import { c as create_ssr_component, a as add_attribute, v as validate_component, e as escape } from "./index3.js";
import { I as Icon } from "./icon.js";
import formatHighlight from "json-format-highlight";
import { C as Copy_button } from "./copy-button.js";
const Collapse = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let { iconId = "" } = $$props;
  let { sectionTitle = "" } = $$props;
  let { sectionAditionalInfo = null } = $$props;
  let { hideIcon = false } = $$props;
  let { showDetails = false } = $$props;
  if ($$props.iconId === void 0 && $$bindings.iconId && iconId !== void 0)
    $$bindings.iconId(iconId);
  if ($$props.sectionTitle === void 0 && $$bindings.sectionTitle && sectionTitle !== void 0)
    $$bindings.sectionTitle(sectionTitle);
  if ($$props.sectionAditionalInfo === void 0 && $$bindings.sectionAditionalInfo && sectionAditionalInfo !== void 0)
    $$bindings.sectionAditionalInfo(sectionAditionalInfo);
  if ($$props.hideIcon === void 0 && $$bindings.hideIcon && hideIcon !== void 0)
    $$bindings.hideIcon(hideIcon);
  if ($$props.showDetails === void 0 && $$bindings.showDetails && showDetails !== void 0)
    $$bindings.showDetails(showDetails);
  return `<div class="collapse-arrow collapse rounded-md border"><input type="checkbox"${add_attribute("checked", showDetails, 1)}>
    <div class="collapse-title flex items-center py-1">${!hideIcon ? `<div class="center h-8 w-8 rounded-full">${validate_component(Icon, "Icon").$$render(
    $$result,
    {
      id: iconId,
      size: "md",
      fill: "success",
      stroke: "success"
    },
    {},
    {}
  )}</div>` : ``}
        <div class="ml-2 flex items-center gap-2"><p class="text-primary">${escape(sectionTitle)}</p>
            ${sectionAditionalInfo ? `<span class="rounded-sm border bg-white/10 px-[0.4rem] text-sm">${escape(sectionAditionalInfo)}</span>` : ``}</div></div>
    <div class="collapse-content">${slots.default ? slots.default({}) : ``}</div></div>`;
});
const Json = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let metadataHTML;
  let { data } = $$props;
  let { label } = $$props;
  if ($$props.data === void 0 && $$bindings.data && data !== void 0)
    $$bindings.data(data);
  if ($$props.label === void 0 && $$bindings.label && label !== void 0)
    $$bindings.label(label);
  metadataHTML = formatHighlight(JSON.stringify(data || {}, null, 2), {
    keyColor: "#a5a3a3",
    numberColor: "#e8a034",
    stringColor: "#24ae67"
  });
  return `<div class="mb-3"><div class="mt-3 grid grid-cols-12 items-center gap-3 rounded-lg p-1"><div class="col-span-2 p-1 md:col-span-1">${label !== "token" && label !== "update-cNFT" ? `<div class="center h-10 w-10 rounded-full bg-secondary">${validate_component(Icon, "Icon").$$render($$result, { id: "json", size: "sm" }, {}, {})}</div>` : ``}</div>
        <div class="col-span-10 flex items-center justify-between pr-1 md:col-span-11"><div><h4 class="text-lg font-semibold md:text-sm">${label === "proton" ? `Simple` : `${label === "enriched" ? `Medium` : `${label === "raw" ? `Advanced` : ``}`}`}</h4>
                <h3 class="mr-2 text-xs opacity-50">${label === "proton" ? `Parsed transaction data from XRAY&#39;s Proton` : `${label === "enriched" ? `Enriched transaction data from the Helius API` : `${label === "raw" ? `Raw transaction data from the Solana RPC` : ``}`}`}</h3></div>
            <div class="flex items-center">${label === "token" || label === "update-cNFT" ? `<h3 class="mr-2 text-xs">Copy JSON</h3>` : ``}
                ${validate_component(Copy_button, "CopyButton").$$render($$result, { text: JSON.stringify(data, null, 2) }, {}, {})}
                ${label !== "token" && label !== "update-cNFT" ? `<button class="btn-ghost btn-sm btn">${`${validate_component(Icon, "Icon").$$render($$result, { id: "fullscreen", size: "sm" }, {}, {})}`}</button>` : ``}</div></div>
        ${label === "token" || label === "update-cNFT" ? `<div class="code col-span-12 w-full overflow-hidden px-3"><pre><code class="text-xs"><!-- HTML_TAG_START -->${metadataHTML}<!-- HTML_TAG_END --></code></pre></div>` : ``}</div></div>`;
});
const getMimeType = async (url) => {
  try {
    const response = await fetch(url, { method: "HEAD" });
    if (!response.ok) {
      console.error(
        `Failed to fetch MIME type: ${response.status} ${response.statusText}`
      );
      return null;
    }
    return response.headers.get("Content-Type");
  } catch (error) {
    return null;
  }
};
const basisPointsToPercentage = (sellerFeeBasisPoints) => `${sellerFeeBasisPoints / 100}%`;
export {
  Collapse as C,
  Json as J,
  basisPointsToPercentage as b,
  getMimeType as g
};
