import { c as create_ssr_component, e as escape, v as validate_component, d as each, a as add_attribute } from "./index3.js";
import "@solana/web3.js";
import { P as ProtonCustomActionLabelTypes } from "./types.js";
import "@onsol/tldparser";
import "@nifty-oss/asset";
import { t as transactionActionsMetadata } from "./config.js";
import { I as Icon } from "./icon.js";
import { TransactionType } from "helius-sdk";
import { I as IntersectionObserver } from "./IntersectionObserver.js";
import { s as shortenString } from "./shorten-string.js";
import { T as Token_provider } from "./token-provider.js";
const formatDate = (timestamp) => {
  if (!timestamp) {
    return "";
  }
  const date = String(timestamp).length < 13 ? new Date(timestamp * 1e3) : new Date(timestamp);
  return Intl.DateTimeFormat(void 0, {
    hour: "numeric",
    minute: "numeric",
    day: "numeric",
    month: "numeric",
    year: "2-digit"
  }).format(date);
};
const Transaction = create_ssr_component(($$result, $$props, $$bindings, slots) => {
  let { transaction } = $$props;
  let element;
  let intersecting = false;
  const params = new URLSearchParams(window.location.search);
  const network = params.get("network");
  const isMainnetValue = network !== "devnet";
  const supported = Object.keys(transactionActionsMetadata).includes(transaction.type);
  const metadata = supported ? transactionActionsMetadata[transaction.type] : transactionActionsMetadata["UNKNOWN"];
  const formatSource = (str) => str.split("_").map((word) => word.slice(0, 1) + word.slice(1, word.length).toLowerCase()).join(" ");
  if ($$props.transaction === void 0 && $$bindings.transaction && transaction !== void 0)
    $$bindings.transaction(transaction);
  let $$settled;
  let $$rendered;
  do {
    $$settled = true;
    $$rendered = `<div><a href="${"/tx/" + escape(transaction.signature, true) + "?network=" + escape(isMainnetValue ? "mainnet" : "devnet", true)}" class="gradient relative block w-full rounded-lg border border-transparent bg-black pb-1 text-left hover:border-primary"><div class="pointer-events-none relative grid grid-cols-12 gap-3 rounded-lg"><div class="relative"><div class="center absolute -left-5 top-3 z-10 mb-4 rounded-full border bg-black p-2"><div class="opacity-50">${validate_component(Icon, "Icon").$$render($$result, { id: metadata.icon, size: "md" }, {}, {})}</div>
                    ${transaction.type.includes("COMPRESSED") ? `<div class="center absolute -top-5 left-8 z-10 bg-black px-1 text-[10px] text-[#FFD700]">COMPRESSED
                        </div>` : ``}</div></div>
            <div class="pointer-events-none col-span-12 mb-2 px-3 pl-6"><div class="flex justify-between"><div><h3 class="text-xl font-semibold">${escape(metadata.label)}</h3>
                        <div class="flex text-xs">${transaction.source !== "UNKNOWN" && transaction.source !== "SOLANA_PROGRAM_LIBRARY" ? `<div class="mr-2 rounded">${escape(formatSource(transaction.source))}</div>` : ``}
                            <div class="mr-2 rounded"><a data-sveltekit-reload href="${"/tx/" + escape(transaction.signature, true) + "?network=" + escape(isMainnetValue ? "mainnet" : "devnet", true)}" class="link-neutral pointer-events-auto border border-x-0 border-t-0 border-dotted text-xs hover:link-success">${escape(transaction.signature ? shortenString(transaction.signature, 4) : "Unknown")}</a></div></div></div>
                    <h3 class="ml-2 mt-1 text-xs opacity-50">${escape(formatDate(transaction.timestamp))}</h3></div></div></div>

        ${each(transaction.actions, (action, idx) => {
      let address = action?.actionType?.includes("SENT") ? action.sent || "" : action?.actionType?.includes("RECEIVED") ? action.received || "" : action.sent || action.received || "";
      return `

            ${action.actionType !== "UNKNOWN" ? `${validate_component(IntersectionObserver, "IntersectionObserver").$$render(
        $$result,
        {
          once: true,
          rootMargin: "100px",
          element,
          intersecting
        },
        {
          intersecting: ($$value) => {
            intersecting = $$value;
            $$settled = false;
          }
        },
        {
          default: () => {
            return `<div${add_attribute("this", element, 0)}></div>

                    ${intersecting ? `<div class="ml-3">${validate_component(Token_provider, "TokenProvider").$$render($$result, { address }, {}, {
              default: ({ metadata: metadata2, tokenIsLoading }) => {
                return `${tokenIsLoading ? `<div class="grid animate-pulse grid-cols-12 items-center gap-3 rounded-lg"><div class="col-span-2 p-1 md:col-span-1"><div class="max-height-10 aspect-square w-full rounded-full bg-secondary"></div></div>
                                        <div class="col-span-10 flex items-center justify-between md:col-span-11"><div><div class="mb-2 h-3 w-32 animate-pulse rounded-full bg-secondary"></div>
                                                <div class="h-2 w-20 animate-pulse rounded-full bg-secondary"></div></div>
                                            <div class="h-2 w-5 animate-pulse rounded-full bg-secondary"></div></div>
                                    </div>` : `<div class="my-2 w-full rounded-lg text-left"><div class="pointer-events-none relative grid grid-cols-12 items-center gap-3 rounded-lg p-1"><div class="col-span-2 flex items-center p-1 md:col-span-1"><a data-sveltekit-reload href="${"/token/" + escape(metadata2.address, true) + "?network=" + escape(isMainnetValue ? "mainnet" : "devnet", true)}" class="pointer-events-auto mx-2 w-full transition-transform hover:scale-125">${metadata2?.image ? `
                                                        <div style="${"background-image: url('" + escape(metadata2.image, true) + "')"}" class="aspect-square w-8 rounded-lg bg-cover"></div>` : `<div class="flex aspect-square w-8 items-center justify-center rounded-lg bg-secondary opacity-50">${validate_component(Icon, "Icon").$$render($$result, { id: "image", size: "md" }, {}, {})}
                                                        </div>`}
                                                </a></div>

                                            <div class="pointer-events-none col-span-10 flex items-center justify-between md:col-span-11"><div><h4 class="text-lg font-semibold md:text-sm">${escape(metadata2?.name || "Unknown")}</h4>
                                                    ${Object.keys(ProtonCustomActionLabelTypes).includes(action.actionType) ? `<h3 class="flex text-xs"><p class="link-neutral">${escape(transactionActionsMetadata[action?.actionType].label)}</p>
                                                        </h3>` : `${!action?.actionType?.includes("NFT") || action?.actionType === TransactionType.COMPRESSED_NFT_MINT ? `<div class="flex">${action?.actionType?.includes("SENT") && action.to ? `<p class="mr-1 text-xs text-neutral">Sent to
                                                                </p>

                                                                <h3 class="text-xs"><a data-sveltekit-reload href="${"/account/" + escape(action.to, true) + "?network=" + escape(isMainnetValue ? "mainnet" : "devnet", true)}" class="link-neutral pointer-events-auto border border-x-0 border-t-0 border-dotted hover:link-success">${escape(shortenString(action.to))}</a>
                                                                </h3>` : `${action?.actionType?.includes("RECEIVED") && action.from ? `<p class="mr-1 text-xs text-neutral">Received
                                                                    from
                                                                </p>

                                                                <h3 class="text-xs"><a href="${"/account/" + escape(action.from, true) + "?network=" + escape(isMainnetValue ? "mainnet" : "devnet", true)}" class="link-neutral pointer-events-auto border border-x-0 border-t-0 border-dotted hover:link-success">${escape(shortenString(action.from))}</a>
                                                                </h3>` : `${action.from ? `<h3 class="mr-1 text-xs"><a data-sveltekit-reload href="${"/account/" + escape(action.from, true) + "?network=" + escape(isMainnetValue ? "mainnet" : "devnet", true)}" class="link-neutral pointer-events-auto border border-x-0 border-t-0 border-dotted hover:link-success">${escape(shortenString(action.from))}</a>
                                                                    </h3>` : ``}

                                                                <div class="mr-1">${validate_component(Icon, "Icon").$$render($$result, { id: "arrowRight" }, {}, {})}</div>

                                                                ${action.to ? `<h3 class="text-xs"><a data-sveltekit-reload href="${"/account/" + escape(action.to, true) + "?network=" + escape(isMainnetValue ? "mainnet" : "devnet", true)}" class="link-neutral pointer-events-auto border border-x-0 border-t-0 border-dotted hover:link-success">${escape(shortenString(action.to))}</a>
                                                                    </h3>` : ``}`}`}
                                                        </div>` : ``}`}</div>
                                                <div class="mr-2"><div class="absolute -left-3 top-1/2 h-0.5 w-3 -translate-y-1/2 rounded-full bg-secondary"></div>
                                                    ${action?.actionType?.includes("RECEIVED") || action?.actionType?.includes("NFT_SELL") || action?.actionType?.includes("AIRDROP") || action?.actionType === TransactionType.COMPRESSED_NFT_MINT ? `<h3 class="text-bold text-success">+ ${escape(action.amount.toLocaleString())}
                                                        </h3>` : `${action?.actionType?.includes("SENT") || action?.actionType?.includes("NFT_BUY") ? `<h3 class="text-bold text-error">- ${escape(action.amount.toLocaleString())}
                                                        </h3>` : `${action?.actionType?.includes("BURN") ? `<h3 class="text-bold text-warning">- ${escape(action.amount.toLocaleString())}
                                                        </h3>` : `${action?.amount ? `<h3 class="text-bold">${escape(action.amount.toLocaleString())}
                                                        </h3>` : ``}`}`}`}</div>
                                            </div></div>
                                    </div>`}
                            `;
              }
            })}
                        </div>` : ``}
                `;
          }
        }
      )}` : ``}`;
    })}</a></div>`;
  } while (!$$settled);
  return $$rendered;
});
export {
  Transaction as T
};
