import { TransactionType, Source } from "helius-sdk";
import { LAMPORTS_PER_SOL } from "@solana/web3.js";
const traverseAccountData = (accountData, accounts) => {
  accountData.forEach((data) => {
    if (data.nativeBalanceChange !== 0 || data.tokenBalanceChanges && data.tokenBalanceChanges.length > 0) {
      if (data.nativeBalanceChange !== 0) {
        const amount = data.nativeBalanceChange / LAMPORTS_PER_SOL;
        const mint = SOL;
        if (data.tokenBalanceChanges && data.tokenBalanceChanges.length > 0) {
          const userAccount = data.tokenBalanceChanges[0].userAccount;
          const index = accounts.findIndex(
            (a) => a.account === userAccount
          );
          indexChecker(accounts, index, userAccount, amount, mint);
        } else {
          const account = data.account;
          const index = accounts.findIndex(
            (a) => a.account === account
          );
          indexChecker(accounts, index, account, amount, mint);
        }
      }
      if (data.tokenBalanceChanges && data.tokenBalanceChanges.length !== null) {
        for (let j = 0; j < data.tokenBalanceChanges.length; j++) {
          const tokenBalanceData = data.tokenBalanceChanges[j];
          const mint = tokenBalanceData.mint;
          const account = tokenBalanceData.userAccount;
          const index = accounts.findIndex(
            (a) => a.account === tokenBalanceData.userAccount
          );
          const nativeIndex = accounts.findIndex(
            (a) => a.account === account
          );
          let amount;
          if (tokenBalanceData.rawTokenAmount.decimals === 0) {
            amount = parseInt(
              tokenBalanceData.rawTokenAmount.tokenAmount
            );
          } else {
            amount = parseInt(
              tokenBalanceData.rawTokenAmount.tokenAmount
            ) / 10 ** tokenBalanceData.rawTokenAmount.decimals;
          }
          if (!(nativeIndex !== -1 && accounts[nativeIndex].changes[0].amount === amount)) {
            indexChecker(accounts, index, account, amount, mint);
          }
        }
      }
    }
  });
};
const indexChecker = (accounts, index, account, amount, mint) => {
  if (index !== -1) {
    const i = accounts[index].changes.findIndex((a) => a.mint === mint);
    if (i !== -1) {
      accounts[index].changes[i].amount += amount;
    } else {
      accounts[index].changes.push({ amount, mint });
    }
  } else {
    accounts.push({
      account,
      changes: [{ amount, mint }]
    });
  }
};
const rentTransferCheck = (amount) => {
  if (amount <= 4120320) {
    return true;
  }
  return false;
};
const traverseNativeTransfers = (nativeTransfers, actions, address) => {
  for (let i = 0; i < nativeTransfers.length; i++) {
    const tx = nativeTransfers[i];
    if (!rentTransferCheck(tx.amount)) {
      const from = tx.fromUserAccount || "";
      const to = tx.toUserAccount || "";
      const amount = tx.amount / LAMPORTS_PER_SOL;
      if (!address) {
        actions.push({
          actionType: "TRANSFER",
          amount,
          from,
          sent: SOL,
          to
        });
      } else if (tx.fromUserAccount !== address && tx.toUserAccount !== address) {
        actions.push({
          actionType: "TRANSFER",
          amount,
          from,
          sent: SOL,
          to
        });
      } else {
        let actionType = "";
        if (tx.fromUserAccount === address) {
          actionType = "SENT";
        } else if (tx.toUserAccount === address) {
          actionType = "RECEIVED";
        }
        if (actionType === "SENT") {
          actions.push({
            actionType,
            amount,
            from,
            sent: SOL,
            to
          });
        } else if (actionType === "RECEIVED") {
          actions.push({
            actionType,
            amount,
            from,
            received: SOL,
            to
          });
        }
      }
    }
  }
};
const traverseTokenTransfers = (tokenTransfers, actions, address) => {
  for (let i = 0; i < tokenTransfers.length; i++) {
    const tx = tokenTransfers[i];
    const from = tx.fromUserAccount || "";
    const to = tx.toUserAccount || "";
    const amount = tx.tokenAmount;
    if (!address) {
      const sent = tx.mint;
      actions.push({
        actionType: "TRANSFER",
        amount,
        from,
        sent,
        to
      });
    } else {
      let actionType = "";
      if (tx.fromUserAccount === address) {
        actionType = "SENT";
      } else if (tx.toUserAccount === address) {
        actionType = "RECEIVED";
      }
      if (actionType === "SENT") {
        const sent = tx.mint;
        actions.push({
          actionType,
          amount,
          from,
          sent,
          to
        });
      } else if (actionType === "RECEIVED") {
        const received = tx.mint;
        actions.push({
          actionType,
          amount,
          from,
          received,
          to
        });
      }
    }
  }
};
const parseBurn = (transaction, address) => {
  const {
    tokenTransfers = [],
    nativeTransfers = [],
    accountData = [],
    signature,
    timestamp,
    type,
    source
  } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  if (tokenTransfers === null || nativeTransfers === null) {
    return {
      accounts: [],
      actions: [],
      fee,
      primaryUser: "",
      signature,
      source,
      timestamp,
      type: "BURN"
    };
  }
  const primaryUser = tokenTransfers[0]?.fromUserAccount || "";
  const actions = [];
  const accounts = [];
  for (let i = 0; i < tokenTransfers.length; i++) {
    const tx = tokenTransfers[i];
    const from = tx.fromUserAccount || "";
    const to = tx.toUserAccount || "";
    const amount = tx.tokenAmount;
    let actionType = "";
    if (!address) {
      if (to === "") {
        const sent = tx.mint;
        actions.push({
          actionType: type,
          amount,
          from,
          sent,
          to
        });
      } else {
        actions.push({
          actionType: "TRANSFER",
          amount,
          from,
          sent: tx.mint,
          to
        });
      }
    } else {
      if (to === "") {
        const sent = tx.mint;
        actions.push({
          actionType: type,
          amount,
          from,
          sent,
          to
        });
      } else {
        if (tx.fromUserAccount === address) {
          actionType = "SENT";
        } else if (tx.toUserAccount === address) {
          actionType = "RECEIVED";
        }
        if (actionType === "SENT") {
          const sent = tx.mint;
          actions.push({
            actionType,
            amount,
            from,
            sent,
            to
          });
        } else if (actionType === "RECEIVED") {
          const received = tx.mint;
          actions.push({
            actionType,
            amount,
            from,
            received,
            to
          });
        }
      }
    }
  }
  traverseNativeTransfers(nativeTransfers, actions, address);
  traverseAccountData(accountData, accounts);
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const parseBorrowFox = (transaction, address) => {
  const { type, source, signature, timestamp, tokenTransfers, accountData } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  const actions = [];
  const accounts = [];
  if (tokenTransfers === null) {
    return {
      accounts,
      actions,
      fee,
      primaryUser: "",
      signature,
      source,
      timestamp,
      type
    };
  }
  const primaryUser = tokenTransfers[0]?.fromUserAccount || "";
  for (let i = 0; i < tokenTransfers.length; i++) {
    const tx = tokenTransfers[i];
    const from = tx?.fromUserAccount || "";
    const to = tx?.toUserAccount || "";
    const amount = tx?.tokenAmount;
    if (i === 0) {
      if (!address) {
        const sent = tx?.mint;
        actions.push({
          actionType: "TRANSFER",
          amount,
          from,
          sent,
          to
        });
      } else {
        const actionType = tx.fromUserAccount === address ? "TRANSFER_SENT" : "TRANSFER_RECEIVED";
        if (actionType === "TRANSFER_SENT") {
          const sent = tx?.mint;
          actions.push({
            actionType,
            amount,
            from,
            sent,
            to
          });
        } else if (actionType === "TRANSFER_RECEIVED") {
          const received = tx?.mint;
          actions.push({
            actionType,
            amount,
            from,
            received,
            to
          });
        }
      }
    } else if (i === 1) {
      const sent = tx?.mint;
      actions.push({
        actionType: "BURN",
        amount,
        from,
        sent,
        to
      });
    }
  }
  traverseAccountData(accountData, accounts);
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const parseLoanFox = (transaction) => {
  const { signature, timestamp, type, source, accountData } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  const actions = [];
  const accounts = [];
  if (!accountData) {
    return {
      accounts,
      actions,
      fee,
      primaryUser: "",
      signature,
      source,
      timestamp,
      type
    };
  }
  const primaryUser = accountData[0]?.account || "";
  const sent = accountData[8]?.account;
  actions.push({
    actionType: "FREEZE",
    amount: 0,
    from: primaryUser,
    sent,
    to: ""
  });
  traverseAccountData(accountData, accounts);
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const generateDefaultTransaction = (type) => ({
  ...unknownProtonTransaction,
  type
});
const generateNftTransaction = ({
  transaction,
  event,
  primaryUser,
  accounts,
  actions
}) => ({
  ...generateDefaultTransaction(transaction.type),
  accounts,
  actions,
  fee: transaction.fee / LAMPORTS_PER_SOL,
  primaryUser,
  signature: event.signature,
  source: event.source,
  timestamp: event.timestamp * 1e3
});
const parseNftSale = (transaction, address) => {
  const nftEvent = transaction.events.nft;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const actions = [];
  const accounts = [];
  traverseAccountData(transaction.accountData, accounts);
  if (address) {
    let actionType = "NFT_SALE";
    if (nftEvent.buyer === address) {
      actionType = "NFT_BUY";
    } else if (nftEvent.seller === address) {
      actionType = "NFT_SELL";
    }
    transaction.type = actionType;
    if (actionType === "NFT_BUY") {
      actions.push(
        {
          actionType: "SENT",
          amount: nftEvent.amount / LAMPORTS_PER_SOL,
          from: nftEvent.buyer,
          sent: SOL,
          to: nftEvent.seller
        },
        {
          actionType: "RECEIVED",
          amount: 1,
          from: nftEvent.seller,
          received: (nftEvent.nfts || [{}])[0]?.mint,
          to: nftEvent.buyer
        }
      );
      return generateNftTransaction({
        accounts,
        actions,
        event: nftEvent,
        primaryUser: nftEvent.buyer,
        transaction
      });
    } else if (actionType === "NFT_SELL") {
      actions.push(
        {
          actionType: "SENT",
          amount: 1,
          from: nftEvent.seller,
          sent: (nftEvent.nfts || [{}])[0]?.mint,
          to: nftEvent.buyer
        },
        {
          actionType: "RECEIVED",
          amount: nftEvent.amount / LAMPORTS_PER_SOL,
          from: nftEvent.buyer,
          received: SOL,
          to: nftEvent.seller
        }
      );
      return generateNftTransaction({
        accounts,
        actions,
        event: nftEvent,
        primaryUser: nftEvent.seller,
        transaction
      });
    }
  }
  actions.push(
    {
      actionType: "TRANSFER",
      amount: nftEvent.amount / LAMPORTS_PER_SOL,
      from: nftEvent.buyer,
      sent: SOL,
      to: nftEvent.seller
    },
    {
      actionType: "TRANSFER",
      amount: 1,
      from: nftEvent.seller,
      received: (nftEvent.nfts || [{}])[0]?.mint,
      to: nftEvent.buyer
    }
  );
  return generateNftTransaction({
    accounts,
    actions,
    event: nftEvent,
    primaryUser: nftEvent.seller,
    transaction
  });
};
const parseNftList = (transaction) => {
  const nftEvent = transaction.events.nft;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const accounts = [];
  traverseAccountData(transaction.accountData, accounts);
  return generateNftTransaction({
    accounts,
    actions: [
      {
        // @ts-ignore
        actionType: "NFT_LISTING",
        amount: nftEvent.amount / LAMPORTS_PER_SOL,
        from: nftEvent.seller,
        sent: (nftEvent.nfts || [{}])[0]?.mint,
        to: ""
      }
    ],
    event: nftEvent,
    primaryUser: nftEvent.seller,
    transaction
  });
};
const parseNftCancelList = (transaction) => {
  const nftEvent = transaction.events.nft;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const accounts = [];
  traverseAccountData(transaction.accountData, accounts);
  return generateNftTransaction({
    accounts,
    actions: [
      {
        // @ts-ignore
        actionType: "NFT_CANCEL_LISTING",
        amount: nftEvent.amount / LAMPORTS_PER_SOL,
        from: nftEvent.seller,
        sent: (nftEvent.nfts || [{}])[0]?.mint,
        to: ""
      }
    ],
    event: nftEvent,
    primaryUser: nftEvent.seller,
    transaction
  });
};
const parseNftBid = (transaction) => {
  const nftEvent = transaction.events.nft;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const accounts = [];
  traverseAccountData(transaction.accountData, accounts);
  return generateNftTransaction({
    accounts,
    actions: [
      {
        // @ts-ignore
        actionType: "NFT_BID",
        amount: nftEvent.amount / LAMPORTS_PER_SOL,
        from: "",
        sent: (nftEvent.nfts || [{}])[0]?.mint,
        to: nftEvent.buyer
      }
    ],
    event: nftEvent,
    primaryUser: nftEvent.seller,
    transaction
  });
};
const parseNftCancelBid = (transaction) => {
  const nftEvent = transaction.events.nft;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const accounts = [];
  traverseAccountData(transaction.accountData, accounts);
  return generateNftTransaction({
    accounts,
    actions: [
      {
        // @ts-ignore
        actionType: "NFT_BID_CANCELLED",
        amount: nftEvent.amount / LAMPORTS_PER_SOL,
        from: "",
        sent: (nftEvent.nfts || [{}])[0]?.mint,
        to: nftEvent.buyer
      }
    ],
    event: nftEvent,
    primaryUser: nftEvent.seller,
    transaction
  });
};
const parseNftGlobalBid = (transaction, address) => {
  const nftEvent = transaction.events.nft;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const accounts = [];
  traverseAccountData(transaction.accountData, accounts);
  return generateNftTransaction({
    accounts,
    actions: [
      {
        // @ts-ignore
        actionType: "NFT_GLOBAL_BID",
        amount: nftEvent.amount / LAMPORTS_PER_SOL,
        from: nftEvent.buyer,
        sent: SOL,
        to: ""
      }
    ],
    event: nftEvent,
    primaryUser: nftEvent.buyer,
    transaction
  });
};
const parseNftMint = (transaction, address) => {
  const nftEvent = transaction.events.nft;
  const { source, nativeTransfers, accountData } = transaction;
  if (!nftEvent || !nativeTransfers) {
    return generateDefaultTransaction(transaction.type);
  }
  const actions = [];
  const accounts = [];
  traverseAccountData(accountData, accounts);
  let mintAmount = 0;
  if (source === "SOLANA_PROGRAM_LIBRARY") {
    for (let i = 0; i < nativeTransfers.length; i++) {
      mintAmount += nativeTransfers[i].amount / LAMPORTS_PER_SOL;
    }
  } else {
    mintAmount = nftEvent.amount / LAMPORTS_PER_SOL;
  }
  if (!address) {
    actions.push(
      {
        actionType: "TRANSFER",
        amount: mintAmount,
        from: nftEvent.buyer,
        sent: SOL,
        to: ""
      },
      {
        actionType: "TRANSFER",
        amount: 1,
        from: "",
        received: (nftEvent.nfts || [{}])[0]?.mint,
        to: nftEvent.buyer
      }
    );
  } else {
    if (nftEvent.buyer !== address) {
      actions.push({
        actionType: "AIRDROP",
        amount: 1,
        from: "",
        received: (nftEvent.nfts || [{}])[0]?.mint,
        to: nftEvent.buyer
      });
      return generateNftTransaction({
        accounts,
        actions,
        event: nftEvent,
        primaryUser: nftEvent.buyer,
        transaction
      });
    } else {
      actions.push(
        {
          actionType: "SENT",
          amount: mintAmount,
          from: nftEvent.buyer,
          sent: SOL,
          to: ""
        },
        {
          actionType: "RECEIVED",
          amount: 1,
          from: "",
          received: (nftEvent.nfts || [{}])[0]?.mint,
          to: nftEvent.buyer
        }
      );
    }
  }
  return generateNftTransaction({
    accounts,
    actions,
    event: nftEvent,
    primaryUser: nftEvent.buyer,
    transaction
  });
};
function returnCompressedNftEventArray(value) {
  if (Array.isArray(value)) {
    return value;
  } else if (value) {
    return [value];
  } else {
    return [];
  }
}
const parseCompressedNftMint = (transaction, address) => {
  const nftEvent = returnCompressedNftEventArray(
    transaction.events.compressed
  );
  const { signature, timestamp, accountData, type, source } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  const primaryUser = transaction.feePayer;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const actions = [];
  const accounts = [];
  traverseAccountData(accountData, accounts);
  for (let i = 0; i < nftEvent.length; i++) {
    const nftEventAction = nftEvent[i];
    if (!address) {
      actions.push({
        actionType: "TRANSFER",
        amount: 1,
        from: "",
        sent: nftEventAction.assetId,
        to: nftEventAction.newLeafOwner
      });
    } else if (address === nftEventAction.newLeafOwner) {
      actions.push({
        actionType: "AIRDROP",
        amount: 1,
        from: "",
        received: nftEventAction.assetId,
        to: nftEventAction.newLeafOwner
      });
    } else {
      actions.push({
        actionType: "RECEIVED",
        amount: 1,
        from: "",
        received: nftEventAction.assetId,
        to: nftEventAction.newLeafOwner
      });
    }
  }
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const parseCompressedNftTransfer = (transaction, address) => {
  const nftEvent = returnCompressedNftEventArray(
    transaction.events.compressed
  );
  const { signature, timestamp, accountData, type, source } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  const primaryUser = transaction.feePayer;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const actions = [];
  const accounts = [];
  traverseAccountData(accountData, accounts);
  for (let i = 0; i < nftEvent.length; i++) {
    const nftEventAction = nftEvent[i];
    if (!address) {
      actions.push({
        actionType: "TRANSFER",
        amount: 1,
        from: nftEventAction.oldLeafOwner,
        sent: nftEventAction.assetId,
        to: nftEventAction.newLeafOwner
      });
    } else {
      if (address === nftEventAction.oldLeafOwner) {
        actions.push({
          actionType: "TRANSFER_SENT",
          amount: 1,
          from: nftEventAction.oldLeafOwner,
          sent: nftEventAction.assetId,
          to: nftEventAction.newLeafOwner
        });
      } else if (address === nftEventAction.newLeafOwner) {
        actions.push({
          actionType: "TRANSFER_RECEIVED",
          amount: 1,
          from: nftEventAction.oldLeafOwner,
          received: nftEventAction.assetId,
          to: nftEventAction.newLeafOwner
        });
      }
    }
  }
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const parseCompressedNftBurn = (transaction, address) => {
  const nftEvent = returnCompressedNftEventArray(
    transaction.events.compressed
  );
  const { signature, timestamp, accountData, type, source } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  const primaryUser = transaction.feePayer;
  if (!nftEvent) {
    return generateDefaultTransaction(transaction.type);
  }
  const actions = [];
  const accounts = [];
  traverseAccountData(accountData, accounts);
  for (let i = 0; i < nftEvent.length; i++) {
    const nftEventAction = nftEvent[i];
    if (nftEventAction.type === TransactionType.COMPRESSED_NFT_BURN) {
      actions.push({
        actionType: "BURN_NFT",
        amount: 1,
        from: nftEventAction.oldLeafOwner,
        sent: nftEventAction.assetId,
        to: ""
      });
    } else if (nftEventAction.type === TransactionType.COMPRESSED_NFT_MINT) {
      actions.push({
        actionType: "COMPRESSED_NFT_MINT",
        amount: 1,
        from: "",
        sent: nftEventAction.assetId,
        to: nftEventAction.newLeafOwner
      });
    } else {
      actions.push({
        actionType: "COMPRESSED_NFT_TRANSFER",
        amount: 1,
        from: nftEventAction.oldLeafOwner,
        sent: nftEventAction.assetId,
        to: nftEventAction.newLeafOwner
      });
    }
  }
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const parseSwap = (transaction, address) => {
  const {
    type,
    source,
    signature,
    timestamp,
    tokenTransfers,
    nativeTransfers,
    accountData
  } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  if (tokenTransfers === null || nativeTransfers === null) {
    return {
      accounts: [],
      actions: [],
      fee,
      primaryUser: "",
      signature,
      source,
      timestamp,
      type
    };
  }
  const primaryUser = tokenTransfers[0].fromUserAccount || "";
  const actions = [];
  const accounts = [];
  if (source === "HADESWAP") {
    traverseTokenTransfers(tokenTransfers, actions, address);
    traverseNativeTransfers(nativeTransfers, actions, address);
  } else {
    traverseTokenTransfers(tokenTransfers, actions, address);
  }
  traverseAccountData(accountData, accounts);
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const parseTokenMint = (transaction, address) => {
  const {
    signature,
    timestamp,
    accountData,
    tokenTransfers,
    nativeTransfers,
    type,
    source
  } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  if (tokenTransfers === null || nativeTransfers === null) {
    return {
      accounts: [],
      actions: [],
      fee,
      primaryUser: "",
      signature,
      source,
      timestamp,
      type
    };
  }
  const primaryUser = nativeTransfers[0]?.fromUserAccount || "";
  const actions = [];
  const accounts = [];
  traverseTokenTransfers(tokenTransfers, actions, address);
  traverseNativeTransfers(nativeTransfers, actions, address);
  traverseAccountData(accountData, accounts);
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const parseTransfer = (transaction, address) => {
  const {
    signature,
    timestamp,
    accountData,
    tokenTransfers,
    nativeTransfers,
    type,
    source
  } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  if (tokenTransfers === null || nativeTransfers === null) {
    return {
      accounts: [],
      actions: [],
      fee,
      primaryUser: "",
      signature,
      source,
      timestamp,
      type
    };
  }
  const primaryUser = tokenTransfers[0]?.fromUserAccount || "";
  const actions = [];
  const accounts = [];
  traverseTokenTransfers(tokenTransfers, actions, address);
  traverseNativeTransfers(nativeTransfers, actions, address);
  traverseAccountData(accountData, accounts);
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const parseUnknown = (transaction, address) => {
  const {
    signature,
    timestamp,
    type,
    source,
    accountData,
    tokenTransfers,
    nativeTransfers,
    instructions
  } = transaction;
  const fee = transaction.fee / LAMPORTS_PER_SOL;
  if (tokenTransfers === null || nativeTransfers === null) {
    return {
      accounts: [],
      actions: [],
      fee,
      primaryUser: "",
      signature,
      source,
      timestamp,
      type
    };
  }
  const primaryUser = tokenTransfers[0]?.fromUserAccount || nativeTransfers[0]?.fromUserAccount || "";
  const actions = [];
  const accounts = [];
  traverseAccountData(accountData, accounts);
  if (instructions && instructions[0].programId === "xnft5aaToUM4UFETUQfj7NUDUBdvYHTVhNFThEYTm55") {
    let type2 = "XNFT_INSTALL";
    if (instructions[0].accounts.length === 6) {
      type2 = "XNFT_INSTALL";
    } else if (instructions[0].accounts.length === 3) {
      type2 = "XNFT_UNINSTALL";
    }
    return {
      accounts,
      actions,
      fee,
      primaryUser,
      signature,
      source,
      timestamp,
      type: type2
    };
  }
  traverseTokenTransfers(tokenTransfers, actions, address);
  traverseNativeTransfers(nativeTransfers, actions, address);
  return {
    accounts,
    actions,
    fee,
    primaryUser,
    signature,
    source,
    timestamp,
    type
  };
};
const SOL = "So11111111111111111111111111111111111111112";
const ProtonCustomActionLabelTypes = {
  AIRDROP: "Airdropped",
  BURN: "Burned",
  BURN_NFT: "Burned NFT",
  COMPRESSED_NFT_BURN: "Burned NFT",
  FREEZE: "Frozen",
  XNFT_INSTALL: "xNFT Install",
  XNFT_UNINSTALL: "xNFT Uninstall"
};
const unknownProtonTransaction = {
  accounts: [],
  actions: [],
  fee: 0,
  primaryUser: "",
  signature: "",
  source: Source.SYSTEM_PROGRAM,
  timestamp: 0,
  type: "UNKNOWN"
};
const protonParsers = {
  BORROW_FOX: parseBorrowFox,
  BURN: parseBurn,
  BURN_NFT: parseBurn,
  COMPRESSED_NFT_BURN: parseCompressedNftBurn,
  COMPRESSED_NFT_MINT: parseCompressedNftMint,
  COMPRESSED_NFT_TRANSFER: parseCompressedNftTransfer,
  EXECUTE_TRANSACTION: parseTransfer,
  LOAN_FOX: parseLoanFox,
  NFT_BID: parseNftBid,
  NFT_BID_CANCELLED: parseNftCancelBid,
  NFT_CANCEL_LISTING: parseNftCancelList,
  NFT_GLOBAL_BID: parseNftGlobalBid,
  NFT_LISTING: parseNftList,
  NFT_MINT: parseNftMint,
  NFT_SALE: parseNftSale,
  SWAP: parseSwap,
  TOKEN_MINT: parseTokenMint,
  TRANSFER: parseTransfer,
  UNKNOWN: parseUnknown
};
export {
  ProtonCustomActionLabelTypes as P,
  SOL as S,
  protonParsers as p
};
