import { Connection, Keypair, PublicKey } from "@solana/web3.js";
import { AnchorProvider, Program } from "@coral-xyz/anchor";
import { g as getRPCUrl } from "../../../../chunks/get-rpc-url.js";
import "../../../../chunks/index.js";
async function grabIdl(accountAddress, isMainnetValue, apiKey) {
  try {
    const connection = new Connection(
      getRPCUrl(`?api-key=${apiKey}`, isMainnetValue),
      "confirmed"
    );
    const dummyKeypair = Keypair.generate();
    const dummyWallet = {
      publicKey: dummyKeypair.publicKey,
      signAllTransactions: (txs) => Promise.resolve(txs),
      signTransaction: (tx) => Promise.resolve(tx)
    };
    const provider = new AnchorProvider(
      connection,
      dummyWallet,
      AnchorProvider.defaultOptions()
    );
    const accountPubkey = new PublicKey(accountAddress);
    const idl = await Program.fetchIdl(
      accountPubkey,
      provider
    );
    return idl;
  } catch (error) {
    return null;
  }
}
async function GET({ url }) {
  const account = url.searchParams.get("account");
  const isMainnetValue = url.searchParams.get("isMainnetValue");
  const { HELIUS_API_KEY } = process.env;
  if (!HELIUS_API_KEY || !account) {
    return new Response(
      JSON.stringify({
        error: "API key or account parameter not set",
        success: false
      }),
      {
        headers: { "Content-Type": "application/json " },
        status: 400
      }
    );
  }
  try {
    const idl = await grabIdl(
      account,
      isMainnetValue === "true",
      HELIUS_API_KEY
    );
    if (idl) {
      return new Response(JSON.stringify({ idl }), {
        headers: { "Content-Type": "application/json" }
      });
    } else {
      return new Response(
        JSON.stringify({
          error: "IDL not found",
          success: false
        }),
        {
          headers: { "Content-Type": "application/json " },
          status: 404
        }
      );
    }
  } catch (err) {
    return new Response(
      JSON.stringify({
        error: "Failed to fetch IDL",
        success: false
      }),
      {
        headers: { "Content-Type": "application/json " },
        status: 500
      }
    );
  }
}
export {
  GET
};
